Your message dated Sat, 06 Oct 2018 17:36:57 +0100
with message-id <[email protected]>
and subject line Re: Bug#900272: stretch-pu: devscripts/2.17.6+deb9u2
has caused the Debian Bug report #900272,
regarding stretch-pu: devscripts/2.17.6+deb9u2
to be marked as done.
This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.
(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [email protected]
immediately.)
--
900272: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=900272
Debian Bug Tracking System
Contact [email protected] with problems
--- Begin Message ---
Package: release.debian.org
Tags: stretch
User: [email protected]
Usertags: pu
Hi,
I'd like to fix a bunch of sillyness in stretch to make it work smoother
for those who prefer not to run the backports version.
See the attached debdiff.
Thanks for considering.
--
regards,
Mattia Rizzolo
GPG Key: 66AE 2B4A FCCF 3F52 DA18 4D18 4B04 3FCD B944 4540 .''`.
more about me: https://mapreri.org : :' :
Launchpad user: https://launchpad.net/~mapreri `. `'`
Debian QA page: https://qa.debian.org/developer.php?login=mattia `-
diffstat for devscripts-2.17.6+deb9u1 devscripts-2.17.6+deb9u2
debian/changelog | 36 ++++++++++++++++++++++++++++++++++++
debian/control | 6 +++---
scripts/debchange.1 | 2 +-
scripts/debcheckout.pl | 25 +++++++++++++------------
scripts/debdiff.pl | 2 +-
scripts/debsign.bash_completion | 8 ++++----
scripts/uscan.pl | 10 +++++-----
test/test_uscan_mangle | 3 ++-
8 files changed, 65 insertions(+), 27 deletions(-)
diff -Nru devscripts-2.17.6+deb9u1/debian/changelog devscripts-2.17.6+deb9u2/debian/changelog
--- devscripts-2.17.6+deb9u1/debian/changelog 2017-07-14 03:20:04.000000000 +0200
+++ devscripts-2.17.6+deb9u2/debian/changelog 2018-05-28 11:58:54.000000000 +0200
@@ -1,3 +1,39 @@
+devscripts (2.17.6+deb9u2) stretch; urgency=medium
+
+ [ Osamu Aoki ]
+ * uscan:
+ + Fix the new package version regex for filenamemangle. Closes: #869150
+
+ [ Cyril Brulebois ]
+ * debsign: Fix bash completion by using file extensions instead of
+ using globs. Closes: #877440
+
+ [ Mattia Rizzolo ]
+ * debchange:
+ + Update the manpage to mention that --bpo now targets stretch-backports,
+ not jessie-backports. Closes: #877877
+ * uscan:
+ + Apply patch from Stephen Kitt <[email protected]> to support https in the
+ sf.net special redirector. Closes: #879207
+ * test/uscan_mangle:
+ + Use a real newline instead of embedding \n in a shell variable, which
+ isn't portable between dash and bash, fixing FTBFS in systems using bash
+ as /bin/sh.
+ * debian/control:
+ + Change maintainer email from alioth to [email protected].
+ + Move the Git repository to salsa.debian.org.
+
+ [ Christoph Berg ]
+ * debcheckout:
+ + Support salsa.debian.org.
+
+ [ Adam D. Barratt ]
+ * debdiff:
+ + Sort shlibs files before comparing. The order of entries is not
+ significant.
+
+ -- Mattia Rizzolo <[email protected]> Mon, 28 May 2018 11:58:54 +0200
+
devscripts (2.17.6+deb9u1) stretch; urgency=medium
[ Mattia Rizzolo ]
diff -Nru devscripts-2.17.6+deb9u1/debian/control devscripts-2.17.6+deb9u2/debian/control
--- devscripts-2.17.6+deb9u1/debian/control 2017-07-14 03:20:04.000000000 +0200
+++ devscripts-2.17.6+deb9u2/debian/control 2018-05-28 11:55:29.000000000 +0200
@@ -1,7 +1,7 @@
Source: devscripts
Section: devel
Priority: optional
-Maintainer: Devscripts Devel Team <[email protected]>
+Maintainer: Devscripts Maintainers <[email protected]>
Uploaders: James McCoy <[email protected]>,
Martin Zobel-Helas <[email protected]>,
Patrick Schoenfeld <[email protected]>,
@@ -40,8 +40,8 @@
xz-utils,
zip
Testsuite: autopkgtest
-Vcs-Browser: https://anonscm.debian.org/git/collab-maint/devscripts.git
-Vcs-Git: https://anonscm.debian.org/git/collab-maint/devscripts.git
+Vcs-Browser: https://salsa.debian.org/debian/devscripts
+Vcs-Git: https://salsa.debian.org/debian/devscripts.git
Package: devscripts
Architecture: any
diff -Nru devscripts-2.17.6+deb9u1/scripts/debchange.1 devscripts-2.17.6+deb9u2/scripts/debchange.1
--- devscripts-2.17.6+deb9u1/scripts/debchange.1 2017-07-14 03:20:04.000000000 +0200
+++ devscripts-2.17.6+deb9u2/scripts/debchange.1 2018-05-28 11:50:46.000000000 +0200
@@ -251,7 +251,7 @@
distribution. Increment the Debian version.
.TP
.B \-\-bpo
-Increment the Debian release number for an upload to jessie-backports,
+Increment the Debian release number for an upload to stretch-backports,
and add a backport upload changelog comment.
.TP
.BR \-\-local ", " \-l \fIsuffix\fR
diff -Nru devscripts-2.17.6+deb9u1/scripts/debdiff.pl devscripts-2.17.6+deb9u2/scripts/debdiff.pl
--- devscripts-2.17.6+deb9u1/scripts/debdiff.pl 2017-07-14 03:20:04.000000000 +0200
+++ devscripts-2.17.6+deb9u2/scripts/debdiff.pl 2018-05-28 11:57:20.000000000 +0200
@@ -1041,7 +1041,7 @@
foreach my $cf (@cf) {
next unless -f "$dir1/$cf" and -f "$dir2/$cf";
- if ($cf eq 'control' or $cf eq 'conffiles') {
+ if ($cf eq 'control' or $cf eq 'conffiles' or $cf eq 'shlibs') {
for my $file ("$dir1/$cf", "$dir2/$cf") {
my ($fd, @hdrs);
open $fd, '<', $file or fatal "Cannot read $file: $!";
diff -Nru devscripts-2.17.6+deb9u1/scripts/debsign.bash_completion devscripts-2.17.6+deb9u2/scripts/debsign.bash_completion
--- devscripts-2.17.6+deb9u1/scripts/debsign.bash_completion 2017-07-14 03:20:04.000000000 +0200
+++ devscripts-2.17.6+deb9u2/scripts/debsign.bash_completion 2018-05-28 11:50:46.000000000 +0200
@@ -19,10 +19,10 @@
;;
*)
COMPREPLY=( $(
- compgen -G "${cur}*.changes"
- compgen -G "${cur}*.buildinfo"
- compgen -G "${cur}*.dsc"
- compgen -G "${cur}*.commands"
+ compgen -f -X "!*.changes" -- "$cur"
+ compgen -f -X "!*.buildinfo" -- "$cur"
+ compgen -f -X "!*.dsc" -- "$cur"
+ compgen -f -X "!*.commands" -- "$cur"
compgen -W "$options" | grep "^$cur"
) )
;;
diff -Nru devscripts-2.17.6+deb9u1/scripts/uscan.pl devscripts-2.17.6+deb9u2/scripts/uscan.pl
--- devscripts-2.17.6+deb9u1/scripts/uscan.pl 2017-07-14 03:20:04.000000000 +0200
+++ devscripts-2.17.6+deb9u2/scripts/uscan.pl 2018-05-28 11:50:46.000000000 +0200
@@ -1044,12 +1044,12 @@
the redirector with the watch file:
version=4
- http://sf.net/<project>/ <tar-name>-(.+)\.tar\.gz debian uupdate
+ https://sf.net/<project>/ <tar-name>-(.+)\.tar\.gz debian uupdate
For B<audacity>, set the watch file as:
version=4
- http://sf.net/audacity/ audacity-minsrc-(.+)\.tar\.gz debian uupdate
+ https://sf.net/audacity/ audacity-minsrc-(.+)\.tar\.gz debian uupdate
Please note, you can still use normal functionalities of B<uscan> to set up a
watch file for this site without using the redirector.
@@ -2707,9 +2707,9 @@
}
# Handle sf.net addresses specially
- if (! $bare and $base =~ m%^http://sf\.net/%) {
+ if (! $bare and $base =~ m%^https?://sf\.net/%) {
uscan_verbose "sf.net redirection to qa.debian.org/watch/sf.php\n";
- $base =~ s%^http://sf\.net/%https://qa.debian.org/watch/sf.php/%;
+ $base =~ s%^https?://sf\.net/%https://qa.debian.org/watch/sf.php/%;
$filepattern .= '(?:\?.*)?';
}
# Handle pypi.python.org addresses specially
@@ -3291,7 +3291,7 @@
}
unless ($newversion) {
# uversionmanglesd version is '', make best effort to set it
- $newfile_base =~ m/^.+[-_]?(\d[\-+\.:\~\da-zA-Z]*)(?:\.tar\.(gz|bz2|xz)|\.zip)$/i;
+ $newfile_base =~ m/^.+?[-_]?(\d[\-+\.:\~\da-zA-Z]*)(?:\.tar\.(gz|bz2|xz)|\.zip)$/i;
$newversion = $1;
unless ($newversion) {
uscan_warn "Fix filenamemangle to produce a filename with the correct version\n";
diff -Nru devscripts-2.17.6+deb9u1/test/test_uscan_mangle devscripts-2.17.6+deb9u2/test/test_uscan_mangle
--- devscripts-2.17.6+deb9u1/test/test_uscan_mangle 2017-07-14 03:20:04.000000000 +0200
+++ devscripts-2.17.6+deb9u2/test/test_uscan_mangle 2018-05-28 11:50:46.000000000 +0200
@@ -840,7 +840,8 @@
KEYMODE=BIN
USCAN_HTTP_SERVER="server-head.py"
USERAGENT="foo/bar; baz:12,3.45"
- WATCHLINE='opts="useragent= '$USERAGENT' "'"\n"'@@@url@@@/ (?:.*)/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@ debian uupdate'
+ WATCHLINE='opts="useragent= '$USERAGENT' "'"
+"'@@@url@@@/ (?:.*)/@PACKAGE@@ANY_VERSION@@ARCHIVE_EXT@ debian uupdate'
helperWatchUA
unset USERAGENT
unset USCAN_HTTP_SERVER
signature.asc
Description: PGP signature
--- End Message ---
--- Begin Message ---
Version: 9.5
On Sun, 2018-07-01 at 18:36 +0100, Adam D. Barratt wrote:
> Control: tags -1 + confirmed
>
> On Sat, 2018-06-09 at 22:18 +0200, Mattia Rizzolo wrote:
> > On Mon, May 28, 2018 at 12:06:38PM +0200, Mattia Rizzolo wrote:
> > > I'd like to fix a bunch of sillyness in stretch to make it work
> > > smoother
> > > for those who prefer not to run the backports version.
> >
> > Another bug came in, updated debdiff attached.
> > This time it modified the pos needed a refresh due to a change in
> > line number.
>
> I'd be happy with this update, but please could we look at getting
> the
> "ftbfs" tag addition (trivial as it is) landed in unstable before the
> point release?
This update was actually included in 9.5, but the bug not closed for
some reason (probably because the upload was never marked as accepted,
although I'm not sure why that was...)
Regards,
Adam
--- End Message ---
diff -Nru devscripts-2.17.6+deb9u1/scripts/debcheckout.pl devscripts-2.17.6+deb9u2/scripts/debcheckout.pl
--- devscripts-2.17.6+deb9u1/scripts/debcheckout.pl 2017-07-14 03:20:04.000000000 +0200
+++ devscripts-2.17.6+deb9u2/scripts/debcheckout.pl 2018-05-28 11:52:12.000000000 +0200
@@ -74,13 +74,13 @@
=item B<-a>, B<--auth>
Work in authenticated mode; this means that for known repositories (mainly those
-hosted on S<I<https://alioth.debian.org>>) URL rewriting is attempted before
+hosted on S<I<https://salsa.debian.org>>) URL rewriting is attempted before
checking out, to ensure that the repository can be committed to. For example,
-for Subversion repositories hosted on alioth this means that
-S<I<svn+ssh://svn.debian.org/...>> will be used instead of
-S<I<svn://svn.debian.org/...>>.
+for Git repositories hosted on Salsa this means that
+S<I<[email protected]:...git>> will be used instead of
+S<I<https://salsa.debian.org/...git>>.
-There are built-in rules for alioth.debian.org and github.com. Other hosts
+There are built-in rules for salsa.debian.org, alioth.debian.org and github.com. Other hosts
can be configured using B<DEBCHECKOUT_AUTH_URLS>.
=item B<-d>, B<--details>
@@ -198,9 +198,9 @@
References to matching substrings in the replacement texts are
allowed as usual in Perl by the means of B<$1>, B<$2>, ... and so on.
-This setting can be used to enable authenticated mode for most repositories
-out there. Note that the Debian repositories on S<alioth.debian.org>
-(S<$vcs.debian.org>) are implicitly defined.
+This setting is used to configure the "authenticated mode" location for
+repositories. The Debian repositories on S<salsa.debian.org> are implicitly
+defined, as is S<github.com>.
Here is a sample snippet suitable for the configuration files:
@@ -439,7 +439,7 @@
}
# Patch a given repository URL to ensure that the checked out out repository
# can be committed to. Only works for well known repositories (mainly Alioth's).
sub set_auth($$$$) {
my ($repo_type, $url, $user, $dont_act) = @_;
@@ -450,7 +450,7 @@
$user_local =~ s|(.*)(@)|$1|;
my $user_url = $url;
- # Adjust urls from new-style anonymous access to old-style and then deal
+ # Adjust alioth urls from new-style anonymous access to old-style and then deal
# with adjusting for authentication on alioth
$url =~ s@(?:alioth\.debian\.org/(?:anonscm/bzr|scm/loggerhead/bzr)|anonscm\.debian\.org/bzr(?:/bzr)?)@bzr.debian.org/bzr@;
$url =~ s@(?:alioth\.debian\.org/anonscm/darcs|anonscm\.debian\.org/darcs)@darcs.debian.org/darcs@;
@@ -478,7 +478,8 @@
}
}
when ("git") {
- if ($url =~ m%(/users/|~)%) {
+ if ($url =~ s!^https://salsa.debian.org/!git\@salsa.debian.org:!) {
+ } elsif ($url =~ m%(/users/|~)%) {
$user_url =~ s|^\w+://(git\.debian\.org)/git/users/(.*?)/.*|$2|;
$user_url =~ s|^\w+://(git\.debian\.org)/~(.*?)/.*|$2|;
@@ -505,7 +506,7 @@
if ($url eq $old_url) { # last attempt: try with user-defined rules
$url = user_set_auth($repo_type, $url);
}
- die "can't use authenticated mode on repository '$url' since it is not a known repository (e.g. alioth)\n"
+ die "can't use authenticated mode on repository '$url' since it is not a known repository (e.g. salsa.debian.org)\n"
if $url eq $old_url;
return $url;
}
@@ -439,7 +439,7 @@
}
# Patch a given repository URL to ensure that the checked out out repository
-# can be committed to. Only works for well known repositories (mainly Alioth's).
+# can be committed to. Only works for well known repositories (mainly Salsa's).
sub set_auth($$$$) {
my ($repo_type, $url, $user, $dont_act) = @_;